@@ -23,7 +23,8 @@ def create_app(name=PKG, **kwargs):
     :param name: name of the app
     :type name: str
     """
-    app = Flask(name, template_folder=files(templates),
+    app = Flask(name, instance_relative_config=True,
+                template_folder=files(templates),
                 static_folder=files(static))
 
     # app = Flask(name)
