@@ -9,6 +9,7 @@ from flask import (Blueprint, render_template, current_app, request,
 from run_depht.run_depht import run_depht
 
 bp = Blueprint("depht", __name__)
+DEPHT_OUTDIR = Path.home()/"Downloads"/"depht"
 
 
 def check_dir(dirpath):
@@ -19,6 +20,7 @@ def check_dir(dirpath):
 
 def make_output_dir():
     """Create directory structure for DEPhT output.
+
     Directory structure is as follows:
     home/Downloads/depht/<date>/<time>
     Output stored within this directory
@@ -33,7 +35,7 @@ def make_output_dir():
     time = timestamp.split(" ")[1]
     time_list = time.split(":")
     time_list[2] = str(round(float(time_list[2])))
-    time = ":".join(time_list)
+    time = "".join(time_list)
 
     month = date_list[1]
     month_name = datetime.strptime(month, "%m")
@@ -43,9 +45,9 @@ def make_output_dir():
 
     # outdir = Path.home()/"Downloads"/("depht_" + timestamp)
 
-    depht_outdir = Path.home()/"Downloads"/"depht"
+    # depht_outdir = Path.home()/"Downloads"/"depht"
 
-    outdir = depht_outdir/date_dir_name/time
+    outdir = Path(DEPHT_OUTDIR/date_dir_name/time)
 
     return outdir
 
@@ -159,7 +161,7 @@ def depht_results():
 
     for infile in infiles:
         # infile = infiles[0]
-        results_dir = outdir/infile.stem
+        results_dir = Path(outdir)/infile.stem
 
         html_file = None
         proph_count = 0
@@ -182,12 +184,6 @@ def depht_results():
             if item.is_dir() and item.name != "tmp_data":
                 proph_count += 1
 
-            '''
-            # will display the html if there is one input file only
-            if len(infiles) == 1:
-                if item.suffix == ".html":
-                    html_file = str(item)
-            '''
             if item.suffix == ".html":
                 html_file = str(item)
                 # html_files.append(html_file)
